==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/PathRecommendationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.PathRecommendationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Represents a path that is recommended to be allowed and its properties
 * @property action The recommendation action of the machine or rule
 * @property common Whether the application is commonly run on the machine
 * @property configurationStatus The configuration status of the machines group or machine or rule
 * @property fileType The type of the file (for Linux files - Executable is used)
 * @property path The full path of the file, or an identifier of the application
 * @property publisherInfo Represents the publisher information of a process/rule
 * @property type The type of the rule to be allowed
 * @property userSids
 * @property usernames
 */
public data class PathRecommendationArgs(
    public val action: Output<String>? = null,
    public val common: Output<Boolean>? = null,
    public val configurationStatus: Output<String>? = null,
    public val fileType: Output<String>? = null,
    public val path: Output<String>? = null,
    public val publisherInfo: Output<PublisherInfoArgs>? = null,
    public val type: Output<String>? = null,
    public val userSids: Output<List<String>>? = null,
    public val usernames: Output<List<UserRecommendationArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.security.inputs.PathRecommendationArgs> {
    override fun toJava(): com.pulumi.azurenative.security.inputs.PathRecommendationArgs =
        com.pulumi.azurenative.security.inputs.PathRecommendationArgs.builder()
            .action(action?.applyValue({ args0 -> args0 }))
            .common(common?.applyValue({ args0 -> args0 }))
            .configurationStatus(configurationStatus?.applyValue({ args0 -> args0 }))
            .fileType(fileType?.applyValue({ args0 -> args0 }))
            .path(path?.applyValue({ args0 -> args0 }))
            .publisherInfo(publisherInfo?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .type(type?.applyValue({ args0 -> args0 }))
            .userSids(userSids?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .usernames(
                usernames?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [PathRecommendationArgs].
 */
@PulumiTagMarker
public class PathRecommendationArgsBuilder internal constructor() {
    private var action: Output<String>? = null

    private var common: Output<Boolean>? = null

    private var configurationStatus: Output<String>? = null

    private var fileType: Output<String>? = null

    private var path: Output<String>? = null

    private var publisherInfo: Output<PublisherInfoArgs>? = null

    private var type: Output<String>? = null

    private var userSids: Output<List<String>>? = null

    private var usernames: Output<List<UserRecommendationArgs>>? = null

    /**
     * @param value The recommendation action of the machine or rule
     */
    @JvmName("wbuiynwuojvmmpkj")
    public suspend fun action(`value`: Output<String>) {
        this.action = value
    }

    /**
     * @param value Whether the application is commonly run on the machine
     */
    @JvmName("jkjqvvxkvjiehsul")
    public suspend fun common(`value`: Output<Boolean>) {
        this.common = value
    }

    /**
     * @param value The configuration status of the machines group or machine or rule
     */
    @JvmName("rfxbcjaptymcohno")
    public suspend fun configurationStatus(`value`: Output<String>) {
        this.configurationStatus = value
    }

    /**
     * @param value The type of the file (for Linux files - Executable is used)
     */
    @JvmName("siwmoigxqblpnnvb")
    public suspend fun fileType(`value`: Output<String>) {
        this.fileType = value
    }

    /**
     * @param value The full path of the file, or an identifier of the application
     */
    @JvmName("svfluddxvyrtdtwn")
    public suspend fun path(`value`: Output<String>) {
        this.path = value
    }

    /**
     * @param value Represents the publisher information of a process/rule
     */
    @JvmName("ypcinsbudblhfuym")
    public suspend fun publisherInfo(`value`: Output<PublisherInfoArgs>) {
        this.publisherInfo = value
    }

    /**
     * @param value The type of the rule to be allowed
     */
    @JvmName("mwkjgmihqcvkxttx")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value
     */
    @JvmName("ggbswtwadjmenxge")
    public suspend fun userSids(`value`: Output<List<String>>) {
        this.userSids = value
    }

    @JvmName("yxyutqcoxjymxdch")
    public suspend fun userSids(vararg values: Output<String>) {
        this.userSids = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("uhctsipfvwmseewf")
    public suspend fun userSids(values: List<Output<String>>) {
        this.userSids = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("lqravmrikpwsrpnx")
    public suspend fun usernames(`value`: Output<List<UserRecommendationArgs>>) {
        this.usernames = value
    }

    @JvmName("ohobufotrcvavbmr")
    public suspend fun usernames(vararg values: Output<UserRecommendationArgs>) {
        this.usernames = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("butwtnsuvivdtqdy")
    public suspend fun usernames(values: List<Output<UserRecommendationArgs>>) {
        this.usernames = Output.all(values)
    }

    /**
     * @param value The recommendation action of the machine or rule
     */
    @JvmName("fpnfapffqguxgbgi")
    public suspend fun action(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Whether the application is commonly run on the machine
     */
    @JvmName("tguejnrwppftsxri")
    public suspend fun common(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.common = mapped
    }

    /**
     * @param value The configuration status of the machines group or machine or rule
     */
    @JvmName("mrqhrynxbgagqocw")
    public suspend fun configurationStatus(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.configurationStatus = mapped
    }

    /**
     * @param value The type of the file (for Linux files - Executable is used)
     */
    @JvmName("luafsbpfrvlcdnwo")
    public suspend fun fileType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileType = mapped
    }

    /**
     * @param value The full path of the file, or an identifier of the application
     */
    @JvmName("yvmmifugywssilsg")
    public suspend fun path(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.path = mapped
    }

    /**
     * @param value Represents the publisher information of a process/rule
     */
    @JvmName("rbtjudvrojnbmwcj")
    public suspend fun publisherInfo(`value`: PublisherInfoArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publisherInfo = mapped
    }

    /**
     * @param argument Represents the publisher information of a process/rule
     */
    @JvmName("civhexvtvbhlggcx")
    public suspend fun publisherInfo(argument: suspend PublisherInfoArgsBuilder.() -> Unit) {
        val toBeMapped = PublisherInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.publisherInfo = mapped
    }

    /**
     * @param value The type of the rule to be allowed
     */
    @JvmName("eqiojnodaemcdrem")
    public suspend fun type(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value
     */
    @JvmName("fqswvodpflsaqjah")
    public suspend fun userSids(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userSids = mapped
    }

    /**
     * @param values
     */
    @JvmName("lxxclpxsnditaebv")
    public suspend fun userSids(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.userSids = mapped
    }

    /**
     * @param value
     */
    @JvmName("pskhxguxqvuohpat")
    public suspend fun usernames(`value`: List<UserRecommendationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.usernames = mapped
    }

    /**
     * @param argument
     */
    @JvmName("eawmiejnlhdlrveu")
    public suspend fun usernames(argument: List<suspend UserRecommendationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            UserRecommendationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.usernames = mapped
    }

    /**
     * @param argument
     */
    @JvmName("wjauyealkioqauyi")
    public suspend fun usernames(vararg argument: suspend UserRecommendationArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            UserRecommendationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.usernames = mapped
    }

    /**
     * @param argument
     */
    @JvmName("mnuftiaapiacngxg")
    public suspend fun usernames(argument: suspend UserRecommendationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(UserRecommendationArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.usernames = mapped
    }

    /**
     * @param values
     */
    @JvmName("lqrmbbuphxvuftxv")
    public suspend fun usernames(vararg values: UserRecommendationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.usernames = mapped
    }

    internal fun build(): PathRecommendationArgs = PathRecommendationArgs(
        action = action,
        common = common,
        configurationStatus = configurationStatus,
        fileType = fileType,
        path = path,
        publisherInfo = publisherInfo,
        type = type,
        userSids = userSids,
        usernames = usernames,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/PathRecommendationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.PathRecommendationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Represents a path that is recommended to be allowed and its properties
 * @property action The recommendation action of the machine or rule
 * @property common Whether the application is commonly run on the machine
 * @property configurationStatus The configuration status of the machines group or machine or rule
 * @property fileType The type of the file (for Linux files - Executable is used)
 * @property path The full path of the file, or an identifier of the application
 * @property publisherInfo Represents the publisher information of a process/rule
 * @property type The type of the rule to be allowed
 * @property userSids
 * @property usernames
 */
public data class PathRecommendationArgs(
    public val action: Output<String>? = null,
    public val common: Output<Boolean>? = null,
    public val configurationStatus: Output<String>? = null,
    public val fileType: Output<String>? = null,
    public val path: Output<String>? = null,
    public val publisherInfo: Output<PublisherInfoArgs>? = null,
    public val type: Output<String>? = null,
    public val userSids: Output<List<String>>? = null,
    public val usernames: Output<List<UserRecommendationArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.security.inputs.PathRecommendationArgs> {
    override fun toJava(): com.pulumi.azurenative.security.inputs.PathRecommendationArgs =
        com.pulumi.azurenative.security.inputs.PathRecommendationArgs.builder()
            .action(action?.applyValue({ args0 -> args0 }))
            .common(common?.applyValue({ args0 -> args0 }))
            .configurationStatus(configurationStatus?.applyValue({ args0 -> args0 }))
            .fileType(fileType?.applyValue({ args0 -> args0 }))
            .path(path?.applyValue({ args0 -> args0 }))
            .publisherInfo(publisherInfo?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .type(type?.applyValue({ args0 -> args0 }))
            .userSids(userSids?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .usernames(
                usernames?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [PathRecommendationArgs].
 */
@PulumiTagMarker
public class PathRecommendationArgsBuilder internal constructor() {
    private var action: Output<String>? = null

    private var common: Output<Boolean>? = null

    private var configurationStatus: Output<String>? = null

    private var fileType: Output<String>? = null

    private var path: Output<String>? = null

    private var publisherInfo: Output<PublisherInfoArgs>? = null

    private var type: Output<String>? = null

    private var userSids: Output<List<String>>? = null

    private var usernames: Output<List<UserRecommendationArgs>>? = null

    /**
     * @param value The recommendation action of the machine or rule
     */
    @JvmName("wchidlgxdcowoxxp")
    public suspend fun action(`value`: Output<String>) {
        this.action = value
    }

    /**
     * @param value Whether the application is commonly run on the machine
     */
    @JvmName("wmqteunqpomagwbc")
    public suspend fun common(`value`: Output<Boolean>) {
        this.common = value
    }

    /**
     * @param value The configuration status of the machines group or machine or rule
     */
    @JvmName("lqcqhckjlqierkxj")
    public suspend fun configurationStatus(`value`: Output<String>) {
        this.configurationStatus = value
    }

    /**
     * @param value The type of the file (for Linux files - Executable is used)
     */
    @JvmName("distcjqjebugbaiq")
    public suspend fun fileType(`value`: Output<String>) {
        this.fileType = value
    }

    /**
     * @param value The full path of the file, or an identifier of the application
     */
    @JvmName("ujcwdocionsidhne")
    public suspend fun path(`value`: Output<String>) {
        this.path = value
    }

    /**
     * @param value Represents the publisher information of a process/rule
     */
    @JvmName("yiqjwpgicxiyhoag")
    public suspend fun publisherInfo(`value`: Output<PublisherInfoArgs>) {
        this.publisherInfo = value
    }

    /**
     * @param value The type of the rule to be allowed
     */
    @JvmName("ttaxhahlukrghfbd")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value
     */
    @JvmName("glcsljqpabkyyabj")
    public suspend fun userSids(`value`: Output<List<String>>) {
        this.userSids = value
    }

    @JvmName("siuiadxijlinmqhc")
    public suspend fun userSids(vararg values: Output<String>) {
        this.userSids = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("ngdvlidxwakmjkdl")
    public suspend fun userSids(values: List<Output<String>>) {
        this.userSids = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("epydhhlwmjiplhkq")
    public suspend fun usernames(`value`: Output<List<UserRecommendationArgs>>) {
        this.usernames = value
    }

    @JvmName("vrbjbnshgfjlgmnk")
    public suspend fun usernames(vararg values: Output<UserRecommendationArgs>) {
        this.usernames = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("twlrbuajtqbyymai")
    public suspend fun usernames(values: List<Output<UserRecommendationArgs>>) {
        this.usernames = Output.all(values)
    }

    /**
     * @param value The recommendation action of the machine or rule
     */
    @JvmName("npqwprpjfqcvaged")
    public suspend fun action(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Whether the application is commonly run on the machine
     */
    @JvmName("ixacyoxkeokjersy")
    public suspend fun common(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.common = mapped
    }

    /**
     * @param value The configuration status of the machines group or machine or rule
     */
    @JvmName("rguyknaxxntoerly")
    public suspend fun configurationStatus(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.configurationStatus = mapped
    }

    /**
     * @param value The type of the file (for Linux files - Executable is used)
     */
    @JvmName("ccpnqntrfisbfntf")
    public suspend fun fileType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileType = mapped
    }

    /**
     * @param value The full path of the file, or an identifier of the application
     */
    @JvmName("xjmdnsnlymmvrjwm")
    public suspend fun path(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.path = mapped
    }

    /**
     * @param value Represents the publisher information of a process/rule
     */
    @JvmName("tuegdqfcrwhuurpx")
    public suspend fun publisherInfo(`value`: PublisherInfoArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publisherInfo = mapped
    }

    /**
     * @param argument Represents the publisher information of a process/rule
     */
    @JvmName("fbimcwggfikhdfqa")
    public suspend fun publisherInfo(argument: suspend PublisherInfoArgsBuilder.() -> Unit) {
        val toBeMapped = PublisherInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.publisherInfo = mapped
    }

    /**
     * @param value The type of the rule to be allowed
     */
    @JvmName("xeqqnntljdpkcsiv")
    public suspend fun type(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value
     */
    @JvmName("cjslmmnhawhakwur")
    public suspend fun userSids(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userSids = mapped
    }

    /**
     * @param values
     */
    @JvmName("hfmokqieieutqcnf")
    public suspend fun userSids(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.userSids = mapped
    }

    /**
     * @param value
     */
    @JvmName("lmdviocadrjwmvvf")
    public suspend fun usernames(`value`: List<UserRecommendationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.usernames = mapped
    }

    /**
     * @param argument
     */
    @JvmName("iiahulfeyhtrdqjy")
    public suspend fun usernames(argument: List<suspend UserRecommendationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            UserRecommendationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.usernames = mapped
    }

    /**
     * @param argument
     */
    @JvmName("hrlstqwbnxcduypr")
    public suspend fun usernames(vararg argument: suspend UserRecommendationArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            UserRecommendationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.usernames = mapped
    }

    /**
     * @param argument
     */
    @JvmName("sdmwpbubtpcvqsoq")
    public suspend fun usernames(argument: suspend UserRecommendationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(UserRecommendationArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.usernames = mapped
    }

    /**
     * @param values
     */
    @JvmName("hfsevxmywjttajbo")
    public suspend fun usernames(vararg values: UserRecommendationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.usernames = mapped
    }

    internal fun build(): PathRecommendationArgs = PathRecommendationArgs(
        action = action,
        common = common,
        configurationStatus = configurationStatus,
        fileType = fileType,
        path = path,
        publisherInfo = publisherInfo,
        type = type,
        userSids = userSids,
        usernames = usernames,
    )
}
